@@ -26,6 +26,10 @@ test_that("weight argument introduces no error",
               serp(rating ~ temp + contact, slope = "parallel",
                    link = "cloglog", reverse=TRUE, weights = rep(1, 72),
                    weight.type = "frequency", data = wine)$coef)
+            expect_vector(
+              serp(rating ~ temp + contact, slope = "parallel",
+                   link = "cloglog", reverse=TRUE, weights = rep(0.1, 72),
+                   weight.type = "analytic", data = wine)$coef)
 
             set.seed(1)
             n <- 30
@@ -65,8 +69,6 @@ test_that("trace and errorMeterics work properly",
                                globalEff = ~ temp + contact,
                                control= list(trace=3),
                                data=wine, subset = c(1:30)))
-
-
             ## checks on errorMetrics
             f1 <- serp(rating ~ temp + contact, link = "logit",
                        slope = "parallel", reverse=FALSE,
@@ -74,7 +76,6 @@ test_that("trace and errorMeterics work properly",
             expect_error(
               errorMetrics(f1$model[,1L], f1$model[,1L],type = "brier"),
               "supply either a matrix or dataframe of fitted values")
-
             e1 <- errorMetrics(f1, type = "brier")
             e2 <- errorMetrics(f1, type = "logloss")
             e3 <- errorMetrics(f1, type = "misclass")
@@ -85,22 +86,33 @@ test_that("trace and errorMeterics work properly",
             p <- mm$fitted.values
 
             expect_error(
-              errorMetrics(mm$y, mm$fitted.values, model= "binary", type = "brier"),
+              errorMetrics(mm$y, mm$fitted.values, type = "brier"),
               "'actual' must be a factor")
-
+            expect_error(
+              errorMetrics(
+                actual = as.factor(mm$y),
+                predicted = mm$fitted.values[-1L]),
+              "unequal lengths of actual and fitted values")
+            expect_error(
+              errorMetrics(mm$y),
+              "please provide actual and predicted values of fit!")
             yna <- factor(c(y,1))
             pna <- c(p, NA)
             y <- factor(mm$y)
 
-            e4 <- errorMetrics(y, p, model= "binary", type = "logloss")
-            e5 <- errorMetrics(y, p, model= "binary", type = "misclass")
+            e4 <- errorMetrics(y, p, type = "logloss")
+            e5 <- errorMetrics(y, p, type = "misclass")
 
             expect_false(any(is.na(c(e1, e2, e3, e4, e5))))
-
             expect_vector(suppressWarnings(
-              errorMetrics(yna, pna, model= "binary", type = "brier")))
-
+              errorMetrics(yna, pna, type = "brier")$value))
+            expect_output(print.errorMetrics(e1))
+            expect_output(print.errorMetrics(e4))
+            expect_output(print.errorMetrics(e5))
+            expect_error(print.errorMetrics('e5'),
+                          "supports only object of class 'errorMetrics'")
+            expect_error(vcov.serp(mm),
+                         "input must be an object of class 'serp'")
             rm(e1, e2, e3, e4, e5, y, p, mm, f1)
 
 })
-
